#!/bin/sh

if [ -n "$EH_PREFIX" ]; then
	export PREFIX="$EH_PREFIX"
fi

if [ -z "$PREFIX" ]; then
	echo "ERROR: set \$PREFIX before sourcing this script!"
	exit 1
fi

SW_VERSION=`sw_vers -productVersion | cut -d. -f1-2`
case $SW_VERSION in
	10.[01])
		echo "unsupported OS version: $SW_VERSION"
		exit 1
		;;
	10.2)
		export MACOSX_DEPLOYMENT_TARGET=10.2
		FREETYPE_CONFIG=$PREFIX/bin/freetype-config
		export EH_USE_CACHE=0
		;;
	10.[34])
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
	*)
		export EH_USE_CACHE=0
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
esac

LDFLAGS=""

#for dir in freetype2 xft2 render1 fontconfig2 xrender1 flex; do
for dir in system-openssl freetype219 flex; do
	if [ -d "$PREFIX/lib/$dir" ]; then
		for incdir in "$PREFIX/lib/$dir/include/freetype2" "$PREFIX/lib/$dir/include"; do
			if [ -d "$incdir" ]; then
				export CPPFLAGS="$CPPFLAGS -I$incdir"
			fi
		done
		export LDFLAGS="-L$PREFIX/lib/$dir/lib $LDFLAGS"
		export PATH="$PREFIX/lib/$dir/bin:$PATH"
		export PKG_CONFIG_PATH="$PREFIX/lib/$dir/lib/pkgconfig"
	fi
done

# -fast, minus the unsafe bits
if [ -d "libltdl" ]; then
	export ACLOCALFLAGS="$ACLOCALFLAGS -I libltdl"
fi
export CFLAGS="-Os -fPIC"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CPPFLAGS -fno-common -no-cpp-precomp -DMACOSX -DARTS_NO_ALARM -I$PREFIX/include -I/usr/X11R6/include"
export FREETYPE_CONFIG
export LIBS="$LIBS -L$PREFIX/lib -L/usr/X11R6/lib"
export SED="sed"

PATH=`echo $PATH | perl -p -e 'for my $entry (split(/:/, $_)) { next if ($entry =~ m,^/usr/local,); push(@path, $entry) }; $_ = join(":", @path)'`
export PATH="$PATH:/usr/X11R6/bin"

export ALL_LIBRARIES="$LDFLAGS -L$PREFIX/lib -L/usr/X11R6/lib"

cat <<END
the following environment is being used:

  ACLOCALFLAGS:             $ACLOCALFLAGS
  CFLAGS:                   $CFLAGS
  CPPFLAGS:                 $CPPFLAGS
  CXXFLAGS:                 $CXXFLAGS
  FREETYPE_CONFIG:          $FREETYPE_CONFIG
  LDFLAGS:                  $LDFLAGS
  LIBS:                     $LIBS
  MACOSX_DEPLOYMENT_TARGET: $MACOSX_DEPLOYMENT_TARGET
  PATH:                     $PATH
  PKG_CONFIG_PATH:          $PKG_CONFIG_PATH

END

if [ "x$EH_USE_CACHE" = "x1" ]; then
	export ac_cv_c_compiler_gnu=yes
	export ac_cv_cxx_compiler_gnu=yes
	export ac_cv_env_CC_set=
	export ac_cv_env_CC_value=
	export ac_cv_env_CFLAGS_set=set
	export ac_cv_env_CFLAGS_value="$CFLAGS"
	export ac_cv_env_CPPFLAGS_set=set
	export ac_cv_env_CPPFLAGS_value="$CPPFLAGS"
	export ac_cv_env_CPP_set=
	export ac_cv_env_CPP_value=
	export ac_cv_env_CXXCPP_set=
	export ac_cv_env_CXXCPP_value=
	export ac_cv_env_CXXFLAGS_set=set
	export ac_cv_env_CXXFLAGS_value="$CXXFLAGS"
	export ac_cv_env_F77_set=
	export ac_cv_env_F77_value=
	export ac_cv_env_FFLAGS_set=
	export ac_cv_env_FFLAGS_value=
	export ac_cv_env_LDFLAGS_set=set
	export ac_cv_env_LDFLAGS_value="$LDFLAGS"
	export ac_cv_env_build_alias_set=
	export ac_cv_env_build_alias_value=
	export ac_cv_env_host_alias_set=
	export ac_cv_env_host_alias_value=
	export ac_cv_env_target_alias_set=
	export ac_cv_env_target_alias_value=
	export ac_cv_exeext=
	export ac_cv_f77_compiler_gnu=no
	export ac_cv_func__NSGetEnviron=yes
	export ac_cv_func_connect=yes
	export ac_cv_func_freeaddrinfo=yes
	export ac_cv_func_gai_strerror=yes
	export ac_cv_func_getaddrinfo=yes
	export ac_cv_func_gethostbyname2=yes
	export ac_cv_func_gethostbyname2_r=no
	export ac_cv_func_gethostbyname_r=no
	export ac_cv_func_getnameinfo=yes
	export ac_cv_func_getpeername=yes
	export ac_cv_func_getprotobyname_r=no
	export ac_cv_func_getservbyname_r=no
	export ac_cv_func_getservbyport_r=no
	export ac_cv_func_getsockname=yes
	export ac_cv_func_getsockopt=yes
	export ac_cv_func_if_nametoindex=yes
	export ac_cv_func_inet_ntoa=yes
	export ac_cv_func_inet_ntop=yes
	export ac_cv_func_inet_pton=yes
	export ac_cv_func_poll=yes
	export ac_cv_func_remove=yes
	export ac_cv_func_shmat=yes
	export ac_cv_func_snprintf=yes
	export ac_cv_func_usleep=yes
	export ac_cv_func_vsnprintf=yes
	export ac_cv_have_dlfcn=yes
	export ac_cv_have_kde='have_kde=yes     ac_kde_includes=$PREFIX/include ac_kde_libraries=$PREFIX/lib'
	export ac_cv_have_qt='have_qt=yes     ac_qt_includes=$PREFIX/include/qt ac_qt_libraries=$PREFIX/lib'
	export ac_cv_header_Carbon_Carbon_h=yes
	export ac_cv_header_CoreAudio_CoreAudio_h=yes
	export ac_cv_header_crt_externs_h=yes
	export ac_cv_header_dlfcn_h=yes
	export ac_cv_header_inttypes_h=yes
	export ac_cv_header_kimiface_h=yes
	export ac_cv_header_knotifyclient_h=yes
	export ac_cv_header_memory_h=yes
	export ac_cv_header_net_if_h=yes
	export ac_cv_header_netinet_in_h=yes
	export ac_cv_header_stdc=yes
	export ac_cv_header_stdint_h=yes
	export ac_cv_header_stdlib_h=yes
	export ac_cv_header_string_h=yes
	export ac_cv_header_strings_h=yes
	export ac_cv_header_sys_bitypes_h=no
	export ac_cv_header_sys_stat_h=yes
	export ac_cv_header_sys_types_h=yes
	export ac_cv_header_unistd_h=yes
	export ac_cv_lib_ICE_IceConnectionNumber=yes
	export ac_cv_lib_c_crypt=yes
	export ac_cv_lib_compat_main=no
	export ac_cv_lib_crypt_crypt=no
	export ac_cv_lib_dl_dlopen=yes
	export ac_cv_lib_dld_shl_unload=no
	export ac_cv_lib_dnet_dnet_ntoa=no
	export ac_cv_lib_dnet_stub_dnet_ntoa=no
	export ac_cv_lib_jpeg_6b=no
	export ac_cv_lib_jpeg_normal=-ljpeg
	export ac_cv_lib_png='-lpng -lz -lm'
	export ac_cv_lib_poll_poll=yes
	export ac_cv_lib_pthread_pthread_create=yes
	export ac_cv_lib_ucb_killpg=no
	export ac_cv_lib_util_main=no
	export ac_cv_lib_z=-lz
	export ac_cv_objext=o
	export ac_cv_path_GMSGFMT=$PREFIX/bin/msgfmt
	export ac_cv_path_MSGFMT=$PREFIX/bin/msgfmt
	export ac_cv_path_XGETTEXT=$PREFIX/bin/xgettext
	export ac_cv_path_install='/usr/bin/install -c'
	export ac_cv_prog_AWK=gawk
	export ac_cv_prog_CPP='gcc-3.3 -E'
	export ac_cv_prog_CXXCPP='g++-3.3 -E'
	export ac_cv_prog_ac_ct_AR=ar
	export ac_cv_prog_ac_ct_CC=gcc-3.3
	export ac_cv_prog_ac_ct_RANLIB=ranlib
	export ac_cv_prog_ac_ct_STRIP=strip
	export ac_cv_prog_cc_g=yes
	export ac_cv_prog_cc_stdc=
	export ac_cv_prog_cxx_g=yes
	export ac_cv_prog_egrep='grep -E'
	export ac_cv_prog_f77_g=no
	export ac_cv_prog_make_make_set=yes
	export ac_cv_sizeof_char_p=4
	export ac_cv_sizeof_int=4
	export ac_cv_sizeof_long=4
	export ac_cv_sizeof_short=2
	export ac_cv_sizeof_size_t=4
	export ac_cv_sizeof_unsigned_long=4
	export ac_cv_type_char_p=yes
	export ac_cv_type_int=yes
	export ac_cv_type_long=yes
	export ac_cv_type_short=yes
	export ac_cv_type_size_t=yes
	export ac_cv_type_struct_addrinfo=yes
	export ac_cv_type_unsigned_long=yes
	export am_cv_CC_dependencies_compiler_type=none
	export am_cv_CXX_dependencies_compiler_type=none
	export kde_cv_all_paths='kde_have_all_paths="yes" 	kde_htmldir="\${datadir}/doc/HTML" 	kde_appsdir="\${datadir}/applnk" 	kde_icondir="\${datadir}/icons" 	kde_sounddir="\${datadir}/sounds" 	kde_datadir="\${datadir}/apps" 	kde_locale="\${datadir}/locale" 	kde_cgidir="\${exec_prefix}/cgi-bin" 	kde_confdir="\${datadir}/config" 	kde_kcfgdir="\${datadir}/config.kcfg" 	kde_mimedir="\${datadir}/mimelnk" 	kde_toolbardir="\${datadir}/toolbar" 	kde_wallpaperdir="\${datadir}/wallpapers" 	kde_templatesdir="\${datadir}/templates" 	kde_bindir="\${exec_prefix}/bin" 	kde_servicesdir="\${datadir}/services" 	kde_servicetypesdir="\${datadir}/servicetypes" 	kde_moduledir="\${libdir}/kde3" 	kde_styledir="\${libdir}/kde3/plugins/styles" 	kde_widgetdir="$PREFIX/lib/kde3/plugins/designer" 	xdg_appsdir="\${datadir}/applications/kde" 	xdg_menudir="\${sysconfdir}/xdg/menus" 	xdg_directorydir="\${datadir}/desktop-directories" 	kde_result=defaults'
	export kde_cv_func_res_init=yes
	export kde_cv_func_strlcat=yes
	export kde_cv_func_strlcpy=yes
	export kde_cv_have_libXext=yes
	export kde_cv_have_x='have_x=yes          kde_x_includes=/usr/X11R6/include kde_x_libraries=/usr/X11R6/lib'
	export kde_cv_path_artsc_config=$PREFIX/bin/artsc-config
	export kde_cv_path_dcopidl=$PREFIX/bin/dcopidl
	export kde_cv_path_dcopidl2cpp=$PREFIX/bin/dcopidl2cpp
	export kde_cv_path_dcopidlng=$PREFIX/bin/dcopidlng
	export kde_cv_path_kconfig_compiler=$PREFIX/bin/kconfig_compiler
	export kde_cv_path_kde_config=$PREFIX/bin/kde-config
	export kde_cv_path_mcopidl=$PREFIX/bin/mcopidl
	export kde_cv_path_meinproc=$PREFIX/bin/meinproc
	export kde_cv_path_moc=$PREFIX/bin/moc
	export kde_cv_path_perl=/usr/bin/perl
	export kde_cv_path_uic=$PREFIX/bin/uic
	export kde_cv_path_xmllint=$PREFIX/bin/xmllint
	export kde_cv_prog_cxx_O0=yes
	export kde_cv_prog_cxx_Wno_long_long=yes
	export kde_cv_prog_cxx_Wnon_virtual_dtor=yes
	export kde_cv_prog_cxx_Wundef=yes
	export kde_cv_prog_cxx_fexceptions=yes
	export kde_cv_prog_cxx_fno_check_new=yes
	export kde_cv_prog_cxx_fno_common=yes
	export kde_cv_prog_cxx_fno_exceptions=yes
	export kde_cv_prog_uic_L=yes
	export kde_cv_prog_uic_nounload=yes
	export kde_cv_proto_res_init=no
	export kde_cv_proto_strlcat=no
	export kde_cv_proto_strlcpy=no
	export kde_cv_qt_jpeg=no
	export kde_cv_socklen_t=yes
	export kde_cv_socklen_t_equiv=socklen_t
	export kde_cv_stl_works=yes
	export kde_cv_uic_plugins=yes
	export lt_cv_deplibs_check_method=pass_all
	export lt_cv_dlopen=dlopen
	export lt_cv_dlopen_libs=-ldl
	export lt_cv_dlopen_self=yes
	export lt_cv_dlopen_self_static=yes
	export lt_cv_file_magic_cmd='$MAGIC_CMD'
	export lt_cv_file_magic_test_file=
	export lt_cv_ld_reload_flag=-r
	export lt_cv_objdir=.libs
	export lt_cv_path_LD=/usr/bin/ld
	export lt_cv_path_LDCXX=/usr/bin/ld
	export lt_cv_path_NM='/usr/bin/nm -p'
	export lt_cv_prog_compiler_c_o=yes
	export lt_cv_prog_compiler_c_o_CXX=yes
	export lt_cv_prog_compiler_rtti_exceptions=no
	export lt_cv_prog_gnu_ld=no
	export lt_cv_prog_gnu_ldcxx=no
	export lt_cv_sys_global_symbol_pipe='sed -n -e '\''s/^.*[ 	]\([BCDEGRST][BCDEGRST]*\)[ 	][ 	]*_\([_A-Za-z][_A-Za-z0-9]*\)$/\1 _\2 \2/p'\'''
	export lt_cv_sys_global_symbol_to_c_name_address='sed -n -e '\''s/^: \([^ ]*\) $/  {\"\1\", (lt_ptr) 0},/p'\'' -e '\''s/^[BCDEGRST] \([^ ]*\) \([^ ]*\)$/  {"\2", (lt_ptr) \&\2},/p'\'''
	export lt_cv_sys_global_symbol_to_cdecl='sed -n -e '\''s/^. .* \(.*\)$/extern int \1;/p'\'''
	export lt_cv_sys_max_cmd_len=65536
	export lt_lt_cv_prog_compiler_c_o='"yes"'
	export lt_lt_cv_prog_compiler_c_o_CXX='"yes"'
	export lt_lt_cv_sys_global_symbol_pipe='"sed -n -e '\''s/^.*[ 	]\\([BCDEGRST][BCDEGRST]*\\)[ 	][ 	]*_\\([_A-Za-z][_A-Za-z0-9]*\\)\$/\\1 _\\2 \\2/p'\''"'
	export lt_lt_cv_sys_global_symbol_to_c_name_address='"sed -n -e '\''s/^: \\([^ ]*\\) \$/  {\\\"\\1\\\", (lt_ptr) 0},/p'\'' -e '\''s/^[BCDEGRST] \\([^ ]*\\) \\([^ ]*\\)\$/  {\"\\2\", (lt_ptr) \\&\\2},/p'\''"'
	export lt_lt_cv_sys_global_symbol_to_cdecl='"sed -n -e '\''s/^. .* \\(.*\\)\$/extern int \\1;/p'\''"'
fi
